@@ -7,7 +7,7 @@ from spark_pipeline_framework.progress_logger.progress_logger import ProgressLog
 from spark_pipeline_framework.proxy_generator.python_proxy_base import PythonProxyBase
 
 
-class FeatureTransformer(PythonProxyBase):
+class FeatureCarrierPythonTransformer(PythonProxyBase):
     # noinspection PyUnusedLocal
     @keyword_only
     def __init__(self,
@@ -16,10 +16,12 @@ class FeatureTransformer(PythonProxyBase):
                  progress_logger: Optional[ProgressLogger] = None,
                  verify_count_remains_same: bool = False
                  ) -> None:
-        super(FeatureTransformer, self).__init__(name=name,
-                                                 parameters=parameters,
-                                                 progress_logger=progress_logger,
-                                                 verify_count_remains_same=verify_count_remains_same)
+        super().__init__(name=name,
+                         parameters=parameters,
+                         progress_logger=progress_logger,
+                         verify_count_remains_same=verify_count_remains_same)
+        assert parameters
+        assert progress_logger
 
     def _transform(self, df: DataFrame) -> DataFrame:
         pass
