@@ -1,35 +1,33 @@
-from typing import Optional, List
+from typing import Optional, List, Dict, Any
 
+# noinspection PyProtectedMember
 from pyspark import keyword_only
-from pyspark.ml.base import Transformer
 from pyspark.ml.param import Param
-from pyspark.ml.util import DefaultParamsReadable, DefaultParamsWritable
 from pyspark.sql.dataframe import DataFrame
 
 from spark_pipeline_framework.logger.yarn_logger import get_logger
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
+from spark_pipeline_framework.transformers.framework_transformer import FrameworkTransformer
 
 
-class FrameworkSelectColumnsTransformer(Transformer, DefaultParamsReadable, DefaultParamsWritable):
+class FrameworkSelectColumnsTransformer(FrameworkTransformer):
     # noinspection PyUnusedLocal
     @keyword_only
     def __init__(self,
-                 name: str = None,
                  view: str = None,
                  drop_columns: Optional[List[str]] = None,
                  keep_columns: Optional[List[str]] = None,
-                 progress_logger: Optional[ProgressLogger] = None,
+                 name: str = None,
+                 parameters: Dict[str, Any] = None,
+                 progress_logger: ProgressLogger = None,
                  verify_count_remains_same: bool = False
                  ) -> None:
-        super().__init__()
+        super().__init__(name=name, parameters=parameters, progress_logger=progress_logger)
         self.logger = get_logger(__name__)
 
         if not view:
             raise ValueError("view is None or empty")
 
-        self.name: Param = Param(self, "name", "")
-        self._setDefault(name=None)  # type: ignore
-
         self.view: Param = Param(self, "view", "")
         self._setDefault(view=None)  # type: ignore
 
@@ -39,9 +37,6 @@ class FrameworkSelectColumnsTransformer(Transformer, DefaultParamsReadable, Defa
         self.keep_columns: Param = Param(self, "keep_columns", "")
         self._setDefault(keep_columns=None)  # type: ignore
 
-        self.progress_logger: Param = Param(self, "progress_logger", "")
-        self._setDefault(progress_logger=None)  # type: ignore
-
         self.verify_count_remains_same: Param = Param(self, "verify_count_remains_same", "")
         self._setDefault(verify_count_remains_same=None)  # type: ignore
 
@@ -51,14 +46,16 @@ class FrameworkSelectColumnsTransformer(Transformer, DefaultParamsReadable, Defa
     # noinspection PyUnusedLocal,PyMissingOrEmptyDocstring,PyPep8Naming
     @keyword_only
     def setParams(self,
-                  name: str = None,
                   view: str = None,
                   drop_columns: Optional[List[str]] = None,
                   keep_columns: Optional[List[str]] = None,
-                  progress_logger: Optional[ProgressLogger] = None,
+                  name: str = None,
+                  parameters: Dict[str, Any] = None,
+                  progress_logger: ProgressLogger = None,
                   verify_count_remains_same: bool = False
                   ):
         kwargs = self._input_kwargs  # type: ignore
+        super().setParams(name=name, parameters=parameters, progress_logger=progress_logger)
         return self._set(**kwargs)  # type: ignore
 
     def _transform(self, df: DataFrame) -> DataFrame:
@@ -89,15 +86,6 @@ class FrameworkSelectColumnsTransformer(Transformer, DefaultParamsReadable, Defa
     def getSql(self) -> str:
         return self.getOrDefault(self.sql)  # type: ignore
 
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setName(self, value):
-        self._paramMap[self.name] = value
-        return self
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getName(self) -> str:
-        return self.getOrDefault(self.name)  # type: ignore
-
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setView(self, value):
         self._paramMap[self.view] = value
@@ -107,15 +95,6 @@ class FrameworkSelectColumnsTransformer(Transformer, DefaultParamsReadable, Defa
     def getView(self) -> str:
         return self.getOrDefault(self.view)  # type: ignore
 
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setProgressLogger(self, value):
-        self._paramMap[self.progress_logger] = value
-        return self
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getProgressLogger(self) -> ProgressLogger:
-        return self.getOrDefault(self.progress_logger)  # type: ignore
-
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setLogSql(self, value):
         self._paramMap[self.log_sql] = value
