@@ -1,28 +1,29 @@
-from typing import Optional
+from typing import Optional, Dict, Any
 
+# noinspection PyProtectedMember
 from pyspark import keyword_only
-from pyspark.ml.base import Transformer
 from pyspark.ml.param import Param
-from pyspark.ml.util import DefaultParamsReadable, DefaultParamsWritable
 from pyspark.sql.dataframe import DataFrame
-from spark_pipeline_framework.progress_logger.progress_log_metric import ProgressLogMetric
 
 from spark_pipeline_framework.logger.yarn_logger import get_logger
+from spark_pipeline_framework.progress_logger.progress_log_metric import ProgressLogMetric
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
+from spark_pipeline_framework.transformers.framework_transformer import FrameworkTransformer
 
 
-class FrameworkSqlTransformer(Transformer, DefaultParamsReadable, DefaultParamsWritable):
+class FrameworkSqlTransformer(FrameworkTransformer):
     # noinspection PyUnusedLocal
     @keyword_only
     def __init__(self,
                  sql: str = None,
-                 name: str = None,
                  view: str = None,
                  log_sql: bool = False,
+                 name: str = None,
+                 parameters: Dict[str, Any] = None,
                  progress_logger: Optional[ProgressLogger] = None,
                  verify_count_remains_same: bool = False
                  ) -> None:
-        super().__init__()
+        super().__init__(name=name, parameters=parameters, progress_logger=progress_logger)
         self.logger = get_logger(__name__)
 
         if not sql:
@@ -34,18 +35,12 @@ class FrameworkSqlTransformer(Transformer, DefaultParamsReadable, DefaultParamsW
         self.sql: Param = Param(self, "sql", "")
         self._setDefault(sql=None)  # type: ignore
 
-        self.name: Param = Param(self, "name", "")
-        self._setDefault(name=None)  # type: ignore
-
         self.view: Param = Param(self, "view", "")
         self._setDefault(view=None)  # type: ignore
 
         self.log_sql: Param = Param(self, "log_sql", "")
         self._setDefault(log_sql=False)  # type: ignore
 
-        self.progress_logger: Param = Param(self, "progress_logger", "")
-        self._setDefault(progress_logger=None)  # type: ignore
-
         self.verify_count_remains_same: Param = Param(self, "verify_count_remains_same", "")
         self._setDefault(verify_count_remains_same=None)  # type: ignore
 
@@ -56,13 +51,15 @@ class FrameworkSqlTransformer(Transformer, DefaultParamsReadable, DefaultParamsW
     @keyword_only
     def setParams(self,
                   sql: str = None,
-                  name: str = None,
                   view: str = None,
                   log_sql: bool = False,
+                  name: str = None,
+                  parameters: Dict[str, Any] = None,
                   progress_logger: Optional[ProgressLogger] = None,
                   verify_count_remains_same: bool = False
                   ):
         kwargs = self._input_kwargs  # type: ignore
+        super().setParams(name=name, parameters=parameters, progress_logger=progress_logger)
         return self._set(**kwargs)  # type: ignore
 
     def _transform(self, df: DataFrame) -> DataFrame:
@@ -75,7 +72,7 @@ class FrameworkSqlTransformer(Transformer, DefaultParamsReadable, DefaultParamsW
             if progress_logger and name:
                 # mlflow opens .txt files inline so we use that extension
                 progress_logger.log_artifact(key=f"{name}.sql.txt", contents=sql_text)
-                progress_logger.write_to_log(name=name)
+                progress_logger.write_to_log(name=name, message=sql_text)
             try:
                 df = df.sql_ctx.sql(sql_text)
             except Exception:
@@ -98,15 +95,6 @@ class FrameworkSqlTransformer(Transformer, DefaultParamsReadable, DefaultParamsW
     def getSql(self) -> str:
         return self.getOrDefault(self.sql)  # type: ignore
 
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setName(self, value):
-        self._paramMap[self.name] = value
-        return self
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getName(self) -> str:
-        return self.getOrDefault(self.name)  # type: ignore
-
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setView(self, value):
         self._paramMap[self.view] = value
@@ -116,15 +104,6 @@ class FrameworkSqlTransformer(Transformer, DefaultParamsReadable, DefaultParamsW
     def getView(self) -> str:
         return self.getOrDefault(self.view)  # type: ignore
 
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setProgressLogger(self, value):
-        self._paramMap[self.progress_logger] = value
-        return self
-
-    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getProgressLogger(self) -> ProgressLogger:
-        return self.getOrDefault(self.progress_logger)  # type: ignore
-
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setLogSql(self, value):
         self._paramMap[self.log_sql] = value
