@@ -3,6 +3,8 @@ import os
 import shutil
 
 # noinspection PyPackageRequirements
+from os import path
+
 import pytest
 from pyspark.sql import SparkSession
 
@@ -69,8 +71,15 @@ def spark_session(request) -> SparkSession:
 
     clean_spark_dir()
 
+    master: str = "spark://localhost:7077"
+    if not path.exists("/Applications/Docker.app"):
+        master = "local[2]"
+        print(f"++++++ Running on local spark: {master} ++++")
+    else:
+        print(f"++++++ Running on docker spark: {master} ++++")
+
     session = SparkSession.builder.appName("pytest-pyspark-local-testing"). \
-        master("spark://localhost:7077"). \
+        master(master). \
         config("spark.ui.showConsoleProgress", "false"). \
         config("spark.sql.shuffle.partitions", "2"). \
         config("spark.default.parallelism", "4"). \
